@@ -1,11 +1,11 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2017-03-03 18:35:46 mtw>
+# Last changed Time-stamp: <2017-03-09 20:50:15 michl>
 
 # Bio::RNA::RNAaliSplit.pm: Handler for horizontally splitting alignments
 
 package Bio::RNA::RNAaliSplit;
 
-use version; our $VERSION = qv('0.03');
+use version; our $VERSION = qv('0.04');
 use Carp;
 use Data::Dumper;
 use Moose;
@@ -88,7 +88,10 @@ sub BUILD {
 		      -displayname_flat => 1} ); # discard position in sequence IDs
     $self->next_aln($self->alignment->next_aln);
     $self->odir( [$self->ifile->dir,$self->odirn] );
-    make_path($self->odir);
+    my @created = make_path($self->odir, {error => \my $err});
+    if (@$err) {
+      confess "ERROR [$this_function] could not create output directory $self->odir";
+    }
     $self->infilebasename(fileparse($self->ifile->basename, qr/\.[^.]*/));
 
     if ($self->has_dump_flag){
@@ -207,7 +210,7 @@ sequence alignments
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
